@@ -1,7 +1,7 @@
 #![forbid(unsafe_code)]
 use anyhow::Result;
 use clap::Parser;
-use dua::{ByteFormat, TraversalSorting};
+use dua::TraversalSorting;
 use std::{fs, io, io::Write, path::PathBuf, process};
 
 mod crossdev;
@@ -38,7 +38,7 @@ fn derive_default_threads(threads: usize) -> usize {
             .processors()
             .get(0)
             .map_or(0, |p| match p.brand() {
-                "Apple M1"|"Apple M1 Pro"|"Apple M1 Max" => 4,
+                "Apple M1"|"Apple M1 Pro"|"Apple M1 Max"|"Apple M2" => 4,
                 other => {
                     eprintln!(
                         "Couldn't auto-configure correct amount of threads for {}. Create an issue here: https://github.com/byron/dua-cli/issues",
@@ -59,7 +59,7 @@ fn main() -> Result<()> {
     let threads = derive_default_threads(opt.threads);
     let walk_options = dua::WalkOptions {
         threads,
-        byte_format: opt.format.map(Into::into).unwrap_or(ByteFormat::Metric),
+        byte_format: opt.format.into(),
         apparent_size: opt.apparent_size,
         count_hard_links: opt.count_hard_links,
         sorting: TraversalSorting::None,
